@@ -114,6 +114,10 @@ current file, collecting Devel::CoverX::Covered information.
 
 B<Edit - Copy Package Name> -- C<C-o e c p> -- Copy the current package name.
 
+B<Edit - Copy Sub Name> -- C<C-o e c s> -- Copy the current sub name.
+
+B<Edit - Copy File Name> -- C<C-o e c f> -- Copy the current file name.
+
 B<Edit - Add Use Statement> -- C<C-o e a u> -- Add a 'use Module'
 statement to the 'use Module' section at the top. Default Module name
 is module at point.
@@ -1213,6 +1217,20 @@ clipboard (kill-ring) and display it in the echo area.
 
 
 
+=head3 Edit - Copy Sub Name
+
+C<C-o e c s> -- Copy the current sub name to the clipboard (kill-ring)
+and display it in the echo area.
+
+
+
+=head3 Edit - Copy File Name
+
+C<C-o e c f> -- Copy the current file name to the clipboard
+(kill-ring) and display it in the echo area.
+
+
+
 =head3 Edit - Add 'use Module' Statement
 
 C<C-o e a u> -- Set mark and add a 'use My::Module;' statement to the
@@ -1779,7 +1797,7 @@ use warnings;
 use utf8;
 
 package Devel::PerlySense;
-$Devel::PerlySense::VERSION = '0.0212';
+$Devel::PerlySense::VERSION = '0.0213';
 
 
 use Spiffy -Base;
